@@ -3,8 +3,7 @@ require 'spec_helper'
 describe 'horizon' do
 
   let :params do
-    { 'secret_key' => 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0',
-      'fqdn'       => '*' }
+    { 'secret_key' => 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0' }
   end
 
   let :pre_condition do
@@ -44,10 +43,12 @@ describe 'horizon' do
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :servername    => 'some.host.tld',
-          :listen_ssl    => false,
-          :extra_params  => {},
-          :redirect_type => 'permanent',
+          :servername     => 'some.host.tld',
+          :listen_ssl     => false,
+          :wsgi_processes => facts[:os_workers],
+          :wsgi_threads   => '1',
+          :extra_params   => {},
+          :redirect_type  => 'permanent',
         })
       end
 
@@ -57,7 +58,7 @@ describe 'horizon' do
           "LOGIN_URL = '#{platforms_params[:root_url]}/auth/login/'",
           "LOGOUT_URL = '#{platforms_params[:root_url]}/auth/logout/'",
           "LOGIN_REDIRECT_URL = '#{platforms_params[:root_url]}/'",
-          "ALLOWED_HOSTS = ['*', ]",
+          "ALLOWED_HOSTS = ['some.host.tld', ]",
           "  'identity': 3,",
           'HORIZON_CONFIG["password_autocomplete"] = "off"',
           'HORIZON_CONFIG["images_panel"] = "legacy"',
@@ -117,6 +118,8 @@ describe 'horizon' do
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
           :instance_options               => {'disable_image' => true, 'disable_instance_snapshot' => true, 'disable_volume' => true, 'disable_volume_snapshot' => true, 'create_volume' => false },
           :file_upload_temp_dir           => '/var/spool/horizon',
+          :wsgi_processes                 => '30',
+          :wsgi_threads                   => '5',
           :secure_cookies                 => true,
           :api_versions                   => {'identity' => 2.0},
           :keystone_multidomain_support   => true,
@@ -129,6 +132,7 @@ describe 'horizon' do
             { 'name' => 'material', 'label' => 'Material', 'path' => 'themes/material' },
           ],
           :default_theme                  => 'default',
+          :simple_ip_management           => true,
           :password_autocomplete          => 'on',
           :images_panel                   => 'angular',
           :create_image_defaults          => {'image_visibility' => 'private'},
@@ -140,13 +144,14 @@ describe 'horizon' do
       it 'generates local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = True',
-          "ALLOWED_HOSTS = ['*', ]",
+          "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           "  'identity': 2.0,",
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
+          'HORIZON_CONFIG["simple_ip_management"] = True',
           'HORIZON_CONFIG["password_autocomplete"] = "on"',
           'HORIZON_CONFIG["images_panel"] = "angular"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
@@ -243,6 +248,23 @@ describe 'horizon' do
       it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
+    context 'with overridden parameters and cache_server_url' do
+      before do
+        params.merge!({
+          :cache_server_url => 'redis://:password@10.0.0.1:6379/1',
+        })
+      end
+
+      it 'generates local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "        'LOCATION': 'redis://:password@10.0.0.1:6379/1',",
+        ])
+      end
+
+      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
+      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
+    end
+
     context 'installs python memcache library when cache_backend is set to memcache' do
       before do
         params.merge!({
@@ -252,11 +274,24 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
-          :tag    => ['openstack']
+          :tag    => ['openstack', 'horizon-package'],
+          :name   => platforms_params[:memcache_package],
          )
       }
     end
 
+    context 'with custom wsgi options' do
+      before do
+        params.merge!( :wsgi_processes => '30',
+                       :wsgi_threads   => '5' )
+      end
+
+      it { should contain_class('horizon::wsgi::apache').with(
+        :wsgi_processes => '30',
+        :wsgi_threads   => '5',
+      )}
+    end
+
     context 'with vhost_extra_params' do
       before do
         params.merge!({
@@ -273,7 +308,6 @@ describe 'horizon' do
       end
     end
 
-
     context 'with ssl enabled' do
       before do
         params.merge!({
@@ -296,6 +330,22 @@ describe 'horizon' do
       end
     end
 
+    context 'with overridden http and https ports' do
+      before do
+        params.merge!({
+          :http_port  => 1028,
+          :https_port => 1029,
+        })
+      end
+
+      it 'configures apache' do
+        is_expected.to contain_class('horizon::wsgi::apache').with({
+          :http_port  => 1028,
+          :https_port => 1029,
+        })
+      end
+    end
+
     context 'with default root_path' do
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
@@ -613,6 +663,26 @@ describe 'horizon' do
         ])
       end
     end
+
+    context 'with keystone_domain_choices' do
+      before do
+        params.merge!({
+          :keystone_domain_choices  => [
+            {'name' => 'default', 'display' => 'The default domain'},
+            {'name' => 'LDAP', 'display' => 'The LDAP Catalog'},
+          ],
+        })
+      end
+      it 'sets OPENSTACK_KEYSTONE_DOMAIN_DROPDOWN in local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'OPENSTACK_KEYSTONE_DOMAIN_DROPDOWN = True',
+          'OPENSTACK_KEYSTONE_DOMAIN_CHOICES = (',
+          "    ('default', 'The default domain'),",
+          "    ('LDAP', 'The LDAP Catalog'),",
+          ')',
+        ])
+      end
+    end
   end
 
   shared_examples_for 'horizon on RedHat' do
@@ -638,23 +708,35 @@ describe 'horizon' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
           :fqdn           => 'some.host.tld',
-          :concat_basedir => '/var/lib/puppet/concat'
+          :concat_basedir => '/var/lib/puppet/concat',
+          :os_workers     => '6'
         }))
       end
 
       let(:platforms_params) do
         case facts[:osfamily]
         when 'Debian'
-          { :config_file       => '/etc/openstack-dashboard/local_settings.py',
-            :package_name      => 'openstack-dashboard',
-            :root_url          => '/horizon',
-            :root_path         => '/var/lib/openstack-dashboard',
-          }
+          if facts[:os_package_type] == 'debian'
+            { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :package_name     => 'openstack-dashboard-apache',
+              :root_url         => '/horizon',
+              :root_path        => '/var/lib/openstack-dashboard',
+              :memcache_package => 'python3-memcache',
+            }
+          else
+            { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :package_name     => 'openstack-dashboard',
+              :root_url         => '/horizon',
+              :root_path        => '/var/lib/openstack-dashboard',
+              :memcache_package => 'python-memcache',
+            }
+          end
         when 'RedHat'
-          { :config_file       => '/etc/openstack-dashboard/local_settings',
-            :package_name      => 'openstack-dashboard',
-            :root_url          => '/dashboard',
-            :root_path         => '/usr/share/openstack-dashboard',
+          { :config_file      => '/etc/openstack-dashboard/local_settings',
+            :package_name     => 'openstack-dashboard',
+            :root_url         => '/dashboard',
+            :root_path        => '/usr/share/openstack-dashboard',
+            :memcache_package => 'python-memcached',
           }
         end
       end
